@@ -24,13 +24,13 @@ class Streams(object):
     def __init__(self):
         self.streams = dict()
 
-    def add_stream(self, engine, handler, buffer):
+    def add_stream(self, engine, handler, buffer, **kwargs):
         assert engine in self.__engines, f"Engine {engine} not recognized"
 
         if engine not in self.streams.keys():
             self.streams[engine] = list()
 
-        self.streams[engine].append([handler, buffer])
+        self.streams[engine].append([handler, buffer, kwargs])
 
     def clear_streams(self):
         self.streams = dict()
@@ -327,19 +327,21 @@ class FileParser(object):
         else:
             self.__reader = None
 
-    def stream_data(self, buffer=DEFAULTBUFFER, engine='default'):
+    def stream_data(self, buffer=DEFAULTBUFFER, engine='default', **kwargs):
         """
         Stream data into chunks
 
         :param buffer: Number of lines per chunk
         :param engine: [Optional] xmlread, csv, open, xlrd, openpyxl, odf, pyxlsb, or default
+        :param kwargs: [Optional] Kwarg values you wish to pass through
         :var data: Either dataframe or list of data
         :var row_start: Row number for first row of data
         :var row_end: Row number for last row of data
+        :var **kwargs: Kwarg values that you specify in stream_data wrapper
         """
 
         def registerhandler(handler):
-            self.__streams.add_stream(engine, handler, buffer)
+            self.__streams.add_stream(engine, handler, buffer, **kwargs)
             return handler
 
         return registerhandler
